# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test
# FileName:      read_excel.py
# Author:       lin
# Datetime:     2024/12/26 19:42
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl
from openpyxl.styles.builtins import title

from APITest_1226 import log
from APITest_1226.common.read_basic_ini import ReadBasicIni
from APITest_1226.common.read_json import read_json
from APITest_1226.common.read_user_ini import ReadUserIni


class ReadExcel:
    @log
    def __init__(self, username, ReadBasicInia=None):
        """获取excel工作簿、工作簿，获取json文件的数据"""
        user_ini = ReadUserIni(username)
        excel_path = user_ini.get_file_path("excel")
        case_path = user_ini.get_file_path("case")
        expect_path = user_ini.get_file_path("expect")
        sql_path = user_ini.get_file_path("sql")
        table_name = user_ini.get_table_name("name")
        self.basic_ini =ReadBasicIni()

        wb = openpyxl.load_workbook(excel_path)
        self.ws = wb[table_name]

        self.case_data = read_json(case_path)
        self.expect_data = read_json(expect_path)
        self.sql_data = read_json(sql_path)

    @log
    def __get_value(self,column,row):
        """获取单元格的数据，并去掉前后空格"""
        cell = self.ws[column+str(row)].value
        if isinstance(cell,str) and cell.strip():
            return cell.strip()

    @log
    def module_name(self,row):
        """获取模块名称"""
        return self.__get_value("b",row)

    @log
    def title_name(self, row):
        """获取用例标题"""
        return self.__get_value("d", row)

    @log
    def level_name(self, row):
        """获取用例级别"""
        return self.__get_value("e", row)

    @log
    def api_name(self, row):
        """获取接口名称"""
        return self.__get_value("c", row)

    @log
    def case_url(self, row):
        """获取访问的url"""
        url = self.__get_value("f", row)
        if url:
            return self.basic_ini.get_host("bpm") +url


    @log
    def case_mime(self,row):
        """获取媒体类型"""
        mime = self.__get_value("g",row)
        if mime:
            return mime.lower()

    @log
    def case_req(self,row):
        """获取请求方式"""
        return self.__get_value("h",row)

    @log
    def case_data1(self,row):
        """获取用例数据"""
        key = self.__get_value("i",row)
        module = self.module_name(row)
        api = self.api_name(row)
        if key:
            return self.case_data[module][api][key]

    @log
    def expect_data1(self, row):
        """获取期望数据"""
        key = self.__get_value("j", row)
        module = self.module_name(row)
        api = self.api_name(row)
        if key:
            return self.expect_data[module][api][key]

    @log
    def sql_data1(self, row):
        """获取sql数据"""
        key = self.__get_value("l", row)
        module = self.module_name(row)
        api = self.api_name(row)
        if key:
            return self.sql_data[module][api][key]

    @log
    def sql_type(self,row):
        """获取sql语句类型"""
        sql_type = self.__get_value("k",row)
        if sql_type:
            return sql_type.lower()

    @log
    def update_key(self, row):
        """获取更新的key"""
        return self.__get_value("m", row)

    @log
    def case_dict(self):
        """将数据放在一个二维列表中"""
        case_dict =[]
        for row in range(2,self.ws.max_row +1):
            url = self.case_url(row)
            mime = self.case_mime(row)
            req = self.case_req(row)
            case = self.case_data1(row)
            expect = self.expect_data1(row)
            sql = self.sql_data1(row)
            sql_type = self.sql_type(row)
            update_key = self.update_key(row)
            level = self.level_name(row)
            title_name = self.title_name(row)
            module = self.module_name(row)
            api = self.api_name(row)
            if url is not None and expect is not None and req is not None:
                case_dict.append([url,mime,req,case,expect,sql,sql_type,update_key,level,title_name,module,api])
        return case_dict




if __name__ == '__main__':
    res = ReadExcel("lisi")
    print(res.case_dict())
    # print(res.case_url(3))










